/*
 * File control definitions.
 *
 * Copyright (C) 2019, 2020, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <l4/sys/compiler.h>

EXTERN_C_BEGIN

/* Definitions for flags_t, employing definitions compatible with fcntl-linux.h
   which can be different from fcntl.h on MIPS and from Newlib. */

#define O_RDONLY        0
#define O_WRONLY        1
#define O_RDWR          2
#define O_APPEND        0x0008
#define O_CREAT         0x0200
#define O_TRUNC         0x0400
#define O_EXCL          0x0800
#define O_NBIO          0x1000
#define O_SYNC          0x2000
#define O_NONBLOCK      0x4000
#define O_NDELAY        O_NONBLOCK
#define O_NOCTTY        0x8000
#define O_DIRECTORY     0x200000

/* System-level functions. */

int open(const char *pathname, int flags, ... /* mode_t mode */);

EXTERN_C_END

/* vim: tabstop=2 expandtab shiftwidth=2
*/
